conntrack

package
v0.50.2 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Jul 10, 2025 License: BSD-3-Clause Imports: 13 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

This section is empty.

Types

type ConnTrack

type ConnTrack struct {
	// contains filtered or unexported fields
}

ConnTrack manages kernel-based conntrack events

func New

func New(flowLogger nftypes.FlowLogger, iface nftypes.IFaceMapper) *ConnTrack

New creates a new connection tracker that interfaces with the kernel's conntrack system

func (*ConnTrack) Close

func (c *ConnTrack) Close() error

Close stops listening for events and cleans up resources

func (*ConnTrack) EnableAccounting

func (c *ConnTrack) EnableAccounting()

EnableAccounting ensures that connection tracking accounting is enabled in the kernel.

func (*ConnTrack) RestoreAccounting

func (c *ConnTrack) RestoreAccounting()

RestoreAccounting restores the connection tracking accounting setting to its original value.

func (*ConnTrack) Start

func (c *ConnTrack) Start(enableCounters bool) error

Start begins tracking connections by listening for conntrack events. This method is idempotent.

func (*ConnTrack) Stop

func (c *ConnTrack) Stop()

Stop stops the connection tracking. This method is idempotent.

Jump to