Documentation
¶
Overview ¶
Package proxycmd provides reusable cobra commands for managing reverse proxy instances. Both the management and combined binaries use these commands, each providing their own StoreOpener to handle config loading and store initialization.
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func NewCommands ¶
func NewCommands(opener StoreOpener) *cobra.Command
NewCommands creates the proxy command tree with the given store opener. Returns the parent "proxy" command with the disconnect-all subcommand.
Types ¶
Click to show internal directories.
Click to hide internal directories.