Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type ConnTrack ¶
type ConnTrack struct {
// contains filtered or unexported fields
}
ConnTrack manages kernel-based conntrack events
func New ¶
func New(flowLogger nftypes.FlowLogger, iface nftypes.IFaceMapper) *ConnTrack
New creates a new connection tracker that interfaces with the kernel's conntrack system
func (*ConnTrack) EnableAccounting ¶
func (c *ConnTrack) EnableAccounting()
EnableAccounting ensures that connection tracking accounting is enabled in the kernel.
func (*ConnTrack) RestoreAccounting ¶
func (c *ConnTrack) RestoreAccounting()
RestoreAccounting restores the connection tracking accounting setting to its original value.
Click to show internal directories.
Click to hide internal directories.